@@ -45,8 +45,8 @@ class DashboardExtension(LavaServerExtension):
             Menu("Tests", reverse("dashboard_app.views.test_list")),
             Menu("Data Views", reverse("dashboard_app.views.data_view_list")),
             Menu("Reports", reverse("dashboard_app.views.report_list")),
-            Menu("Image Reports", reverse("dashboard_app.views.image_report_list")),
-            Menu("[BETA] Filters", reverse("dashboard_app.views.filters_list")),
+            Menu("Image Reports", reverse("dashboard_app.views.images.image_report_list")),
+            Menu("[BETA] Filters", reverse("dashboard_app.views.filters.views.filters_list")),
             ]
         return menu
 
