@@ -16,14 +16,13 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Launch Control.  If not, see <http://www.gnu.org/licenses/>.
 
-import unittest
-
 from mocker import Mocker, expect
+from testtools import TestCase
 
-from dashboard_app.dataview import DataView
+from dashboard_app.models import DataView
 
 
-class DataViewHandlerTests(unittest.TestCase):
+class DataViewHandlerTests(TestCase):
 
     text = """
     <data-view name="foo">
@@ -43,7 +42,8 @@ class DataViewHandlerTests(unittest.TestCase):
     """
 
     def setUp(self):
-        self.dataview = DataView.load_from_xml(self.text) 
+        super(DataViewHandlerTests, self).setUp()
+        self.dataview = DataView.repository.load_from_xml_string(self.text) 
 
     def test_name_parsed_ok(self):
         self.assertEqual(self.dataview.name, "foo")
@@ -74,7 +74,7 @@ class DataViewHandlerTests(unittest.TestCase):
         self.assertEqual(arg.help, "sorting order")
 
 
-class DataViewConnectionTests(unittest.TestCase):
+class DataViewConnectionTests(TestCase):
 
     def test_get_connection_without_sandbox(self):
         # Mock connections['dataview'] to raise ConnectionDoesNotExist
@@ -95,7 +95,6 @@ class DataViewConnectionTests(unittest.TestCase):
         Test for DataView.get_connection()
         """
         # Mock connections['dataview'] to return special connection 
-        from django.db.utils import ConnectionDoesNotExist
         mocker = Mocker()
         connections = mocker.replace("django.db.connections")
         special_connection = mocker.mock()
