@@ -35,17 +35,17 @@ urlpatterns = patterns(
     url(r'^reports/(?P<name>[a-zA-Z0-9-_]+)/$', 'report_detail'),
     url(r'^tests/$', 'test_list'),
     url(r'^tests/(?P<test_id>[^/]+)/$', 'test_detail'),
-    url(r'^filters/$', 'filters_list'),
-    url(r'^filters/\+add$', 'filter_add'),
-    url(r'^filters/\+add-preview-json$', 'filter_preview_json'),
-    url(r'^filters/\+add-cases-for-test-json$', 'filter_add_cases_for_test_json'),
-    url(r'^filters/\+attribute-name-completion-json$', 'filter_attr_name_completion_json'),
-    url(r'^filters/\+attribute-value-completion-json$', 'filter_attr_value_completion_json'),
-    url(r'^filters/~(?P<username>[a-zA-Z0-9-_]+)/(?P<name>[a-zA-Z0-9-_]+)$', 'filter_detail'),
-    url(r'^filters/~(?P<username>[a-zA-Z0-9-_]+)/(?P<name>[a-zA-Z0-9-_]+)/json$', 'filter_json'),
-    url(r'^filters/~(?P<username>[a-zA-Z0-9-_]+)/(?P<name>[a-zA-Z0-9-_]+)/\+edit$', 'filter_edit'),
-    url(r'^filters/~(?P<username>[a-zA-Z0-9-_]+)/(?P<name>[a-zA-Z0-9-_]+)/\+subscribe$', 'filter_subscribe'),
-    url(r'^filters/~(?P<username>[a-zA-Z0-9-_]+)/(?P<name>[a-zA-Z0-9-_]+)/\+delete$', 'filter_delete'),
+    url(r'^filters/$', 'filters.views.filters_list'),
+    url(r'^filters/\+add$', 'filters.views.filter_add'),
+    url(r'^filters/\+add-preview-json$', 'filters.views.filter_preview_json'),
+    url(r'^filters/\+add-cases-for-test-json$', 'filters.views.filter_add_cases_for_test_json'),
+    url(r'^filters/\+attribute-name-completion-json$', 'filters.views.filter_attr_name_completion_json'),
+    url(r'^filters/\+attribute-value-completion-json$', 'filters.views.filter_attr_value_completion_json'),
+    url(r'^filters/~(?P<username>[a-zA-Z0-9-_]+)/(?P<name>[a-zA-Z0-9-_]+)$', 'filters.views.filter_detail'),
+    url(r'^filters/~(?P<username>[a-zA-Z0-9-_]+)/(?P<name>[a-zA-Z0-9-_]+)/json$', 'filters.views.filter_json'),
+    url(r'^filters/~(?P<username>[a-zA-Z0-9-_]+)/(?P<name>[a-zA-Z0-9-_]+)/\+edit$', 'filters.views.filter_edit'),
+    url(r'^filters/~(?P<username>[a-zA-Z0-9-_]+)/(?P<name>[a-zA-Z0-9-_]+)/\+subscribe$', 'filters.views.filter_subscribe'),
+    url(r'^filters/~(?P<username>[a-zA-Z0-9-_]+)/(?P<name>[a-zA-Z0-9-_]+)/\+delete$', 'filters.views.filter_delete'),
     url(r'^xml-rpc/$', linaro_django_xmlrpc.views.handler, 
         name='dashboard_app.views.dashboard_xml_rpc_handler',
         kwargs={
@@ -81,8 +81,8 @@ urlpatterns = patterns(
     url(r'^efforts/(?P<pk>[0-9]+)/$', 'testing_effort_detail'),
     url(r'^efforts/(?P<pk>[0-9]+)/update/$', 'testing_effort_update'),
     url(r'^efforts/(?P<project_identifier>[a-z0-9-]+)/\+new/$', 'testing_effort_create'),
-    url(r'^image-reports/$', 'image_report_list'),
-    url(r'^image-reports/(?P<name>[A-Za-z0-9_-]+)$', 'image_report_detail'),
-    url(r'^api/link-bug-to-testrun', 'link_bug_to_testrun'),
-    url(r'^api/unlink-bug-and-testrun', 'unlink_bug_and_testrun'),
+    url(r'^image-reports/$', 'images.image_report_list'),
+    url(r'^image-reports/(?P<name>[A-Za-z0-9_-]+)$', 'images.image_report_detail'),
+    url(r'^api/link-bug-to-testrun', 'images.link_bug_to_testrun'),
+    url(r'^api/unlink-bug-and-testrun', 'images.unlink_bug_and_testrun'),
 )
